==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/financeiro/model/financeiro_titulo_data.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv, fields
import time


class financeiro_titulo(osv.Model):
    """
    Tabela de titulos.
    Conta todos os documentos a receber e a pagar
    Prefixo: fintit
    """

    from funcoes import _fintit_sacado
    from funcoes import _fintit_moeda_empresa
    from funcoes import _fintit_get_local_cobranca_tipo
    from funcoes import _fintit_get_valores
    from funcoes import _fintit_baixa
    from funcoes import _fintit_vr_pago
    from funcoes import _fintit_get_parametro
    from funcoes import _fintit_is_cheque
    from funcoes import _fintit_get_documento
    from funcoes import _constraint_data_prorrogacao
    from funcoes import _fintit_get_flag
    from funcoes import _fintit_boleto_dados


    """
    PREFIXO PARA NOMES DAS COLUNAS DO FINANCEIRO:

    fintit_

    Ex: fintit_parcela, fintit_vr_desconto, ......
    """

    _name = 'financeiro.titulo'
    _rec_name = 'documento'
    _columns = {
        ######## _____________ integer ____________________
        'id': fields.integer('ID', readonly=True),
        'parcela': fields.integer('Parcela'), # Numero da parcela do documento.
        'bordero': fields.integer('Bordero'), # Numero do bordero
        'fintit_chq_banco': fields.integer('Banco', select=True, help='Numero do banco no Banco Central'),
        'fintit_chq_agencia': fields.integer('Agencia', select=True, help='Numero da agencia bancaria'),

        ######## _____________ float ____________________
        'saldo': fields.float('Saldo', digits=(15, 2)), # Valor do saldo devedor
        'taxa_adm': fields.float('Taxa de administracao', digits=(15, 2)),
        # Valor cobrado pela administradora do cartao, a ser deduzida do valor do titulo na baixa do documento.
        'vr_multa': fields.float('Valor multa', digits=(15, 2)), # Valor da multa pelo atraso
        'vr_original': fields.float('Valor', digits=(15, 2), required=True),
        'vr_juros_dia': fields.float('Valor juros p/dia', digits=(15, 4)), # Valor dos juros por dia de atraso
        'vr_desconto': fields.float('Vr desconto', digits=(15, 2)), # Valor do desconto
        'fintit_vr_acrescimo': fields.float('Vr acrescimo', digits=(15, 2),
                                            help='Valor a ser adicionado ao valor do titulo no '
                                                 'momento da baixa.'),

        ######## _____________ char ____________________
        'fintit_chq_conta': fields.char('Conta', size=10, oldname="chq_conta"), # numero da conta
        'documento': fields.char('Documento', size=30, required=True, select=True), # Numero do documento.
        'observacoes': fields.text('Informacoes complementares'), #dados ou informacoes complementares do titulo
        'fintit_chq_emitente': fields.char('CPF/CNPJ Emitente', size=19, select=True),
        'fintit_nro_autorizacao_cartao': fields.char('Autorizacao', size=10,
                                                     help='Numero de autorizacao qdo for referente a cartao de credito'),

        ######## _____________ date/time ____________________
        'data_aceite': fields.date('Data aceite'), # Data do aceite
        'repasse_data': fields.date('Data de repasse'),
        'data_emissao': fields.date('Emissao', required=True, select=True), # data de emissao do titulo
        'data_vencimento': fields.date('Vencimento original', required=True, select=True),
        'multa_apos_data': fields.date('Multa apos dia'), # Data para cobranca da multa
        'data_prorrogacao': fields.date('Vencimento', required=True, select=True),
        'data_limite_desconto': fields.date('Data limite desconto'), # Data limite para o desconto
        'data_cancelamento': fields.date('Data Cancelamento'), # Data de cancelamento do cupom
        'create_date': fields.datetime('Data criacao'),

        ######## _____________ function ____________________
        'juros': fields.function(_fintit_baixa, multi="baixa", type="float", digits=(15, 2), method=True, store=True,
                                 string='Juros'),
        'fintit_valor_pago': fields.function(_fintit_vr_pago, type="float", digits=(15, 2), method=True, store=False,
                                 string='Valor Pago'),

        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'multa': fields.function(_fintit_baixa, multi="baixa", type="float", digits=(15, 2), method=True, store=True,
                                 string='Multa'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'desconto': fields.function(_fintit_baixa, multi="baixa", type="float", method=True, store=True,
                                    string='Desconto'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'data_baixa': fields.function(_fintit_baixa, multi="baixa", type="date", digits=(15, 2), method=True,
                                      store=True, string='Data da Baixa'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'data_pagamento': fields.function(_fintit_baixa, multi="baixa", type='date', method=True, store=True,
                                          string='Data Pagamento'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'fintit_flag': fields.function(_fintit_get_parametro, multi="parametros", type="boolean", method=True,
                                       store=False, string='Flag'),
        'fintit_parametro_local_cobranca': fields.function(_fintit_get_parametro, multi="parametros", type="boolean",
                                                           method=True, store=False, string='Local Cobranca'),
        'fintit_usar_centro_custos_e_eventos': fields.function(_fintit_get_parametro, multi="parametros",
                                                               type="boolean", method=True, store=False,
                                                               string='Centro custo e eventos'),
        'fintit_ocorrencia_ids': fields.function(_fintit_get_parametro, multi='parametros',
                                                 type='one2many', method=True, store=False,
                                                 string='Ocorrencias', relation='adm.ocorrencia'),
        'fintit_tipo_local_cobranca': fields.function(_fintit_get_local_cobranca_tipo, type="char",
                                                      method=True, store=False,
                                                      string="Tipo Local Cobranca"),
        'fintit_atraso_dias': fields.function(_fintit_get_valores, type="integer", method=True,
                                              store=False, multi="fintit_valores",
                                              string="Atraso(Dias)"),
        'fintit_cheque': fields.function(_fintit_is_cheque, type="boolean", method=True, store=True,
                                         string="Cheque"),
        'fintit_encargos': fields.function(_fintit_get_valores, type="float", method=True,
                                           store=False, multi="fintit_valores", string="Encargos"),
        'fintit_boleto_nosso_numero': fields.function(_fintit_boleto_dados, method=True,
                                                      string='Nosso numero', type='char', size=20,
                                                      store=False, multi='boleto'),
        'fintit_boleto_codigo_barras': fields.function(_fintit_boleto_dados, method=True,
                                                       string='Codigo de barras', type='char',
                                                       size=48, store=False, multi='boleto'),
        'fintit_saldo_corrigido': fields.function(_fintit_get_valores, method=True,
                                                  string='Saldo corrigido', type='float',
                                                  multi="fintit_valores", digits=(15, 2)),

        ######## _____________ selection ____________________
        'state': fields.selection(
            [('A', 'Em aberto'), ('B', 'Baixado'), ('D', 'Devolvido'), ('R', 'Reapresentado'), ('C', 'Cancelado')],
            'Situacao', required=True, readonly=True, size=1),
        'state_banco': fields.selection(
            [('N', 'Nao enviado'), ('E', 'Enviado'), ('C', 'confirmado'), ('R', 'Rejeitado')],
            'Situacao no banco', size=1, readonly=True),
        'tipo_titulo': fields.selection([('R', 'Receber'), ('P', 'Pagar')], 'Tipo titulo', required=True, size=1),
        # Tipo de titulo. \nR=a Receber, \nP=a Pagar
        'tipo_sacado': fields.selection([('C', 'Cliente'), ('F', 'Fornecedor'), ('O', 'Outros')], 'Tipo sacado',
                                        required=True, size=1), # Tipo de sacado\nC=Cliente, \nF=Fornecedor, \nO=Outros
        'tipo_lancamento': fields.selection([('M', 'Manual'), ('A', 'Automatico')], 'Tipo de lancamento', size=1),
        #Tipo de lancamento. \nM Entrada do titulo feito manualmente \nA Entrada do titulo feito automaticamente pelo sistema

        ######## _____________ one2many ____________________
        'cheque_devolucao_ids': fields.one2many('financeiro.cheque.devolucao', 'cheque_id', 'Devolucao', readonly=True),
        # Relacao das devolucoes de um  cheque
        'titulo_historico_ids': fields.one2many('financeiro.titulo.historico', 'titulo_id', 'Historico'),
        'fintit_gerencialmov_ids': fields.one2many('gerencial.movimento', 'titulo_id', 'Movimento'),
        'fintit_baixa_ids': fields.one2many('financeiro.titulo.baixa', 'titulo_id', 'Baixas do Titulo'),
        'fintit_boleto_ids': fields.one2many('financeiro.titulo.boleto', 'fintib_titulo_id',
                                             'Boletos'),

        ######## _____________ many2one ____________________
        'fatura_id': fields.many2one("financeiro.fatura", 'Fatura', ondelete="cascade", select=True), # id da fatura
        'pessoa_id': fields.many2one("adm.pessoa", 'Cliente', ondelete="restrict", required=True, select=True),
        # Id do parceiro(cliente/Fornecedor)
        'company_id': fields.many2one("res.company", 'Empresa', ondelete="cascade", required=True, select=True), # Id da empresa
        'doc_tipo_id': fields.many2one("documento.documento.tipo", 'Tipo de documento', ondelete="restrict",
                                       required=True, select=True), # id do Tipo de documento
        'adm_moeda_id': fields.many2one("adm.moeda", 'Moeda', required=True, ondelete="restrict", select=True),
        # Moeda utilizada no titulo
        'titulo_parent_id': fields.many2one('financeiro.titulo', 'Titulo relacionado', ondelete="restrict"),
        'local_cobranca_id': fields.many2one("financeiro.local.cobranca", 'Local cobranca', ondelete="restrict",
                                             required=True, select=True), # id do local de cobranca
        'repasse_pessoa_id': fields.many2one("adm.pessoa", 'Repassado para', ondelete="restrict", select=True),
        'natureza_cobranca_id': fields.many2one("financeiro.natureza.cobranca", 'Natureza cobranca',
                                                ondelete="restrict", select=True), # id da natureza de cobranca
        'fintit_cancel_user_id': fields.many2one("res.users", 'Usuario', oldname="user"),
        # id do usuario logado no sistema
        'fintit_operacao_id': fields.many2one('financeiro.operacoes', 'Operacao'),
        'fintit_renegociacao_fatura_ids': fields.many2many(
            'financeiro.fatura', 'fatura_renegociacao_titulo', 'titulo_id', 'fatura_id'
            ,'Fatura de renegociacao', select=True),
    }

    _order = 'data_prorrogacao, pessoa_id, documento desc'
    _defaults = {
        'state': lambda *a: 'A',
        'state_banco': lambda *a: 'N',
        'tipo_lancamento': lambda *a: 'M',
        'tipo_sacado': _fintit_sacado,
        'tipo_titulo': 'P',
        'company_id': lambda s, cr, uid, c: s.pool.get('adm.empresa.objeto').getEmpresa(cr, uid, s._name, context=c),
        'data_emissao': lambda *a: time.strftime('%Y-%m-%d'),
        'adm_moeda_id': _fintit_moeda_empresa,
        'doc_tipo_id': lambda s, cr, uid, c:
        s.pool.get('documento.documento.tipo').search(cr, uid, [('sigla', '=', 'DP')], context=c)[0],
        'fintit_flag': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={'fintit_flag': True,
                                                                                  'entrada_titulo_receber': True}),
        'fintit_parametro_local_cobranca': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={
            'fintit_parametro_local_cobranca': True, 'entrada_titulo_receber': True}),
        'fintit_usar_centro_custos_e_eventos': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={
            'fintit_usar_centro_custos_e_eventos': True, 'entrada_titulo_receber': True}),
        'documento': _fintit_get_documento,
    }

    _constraints = [
        (_constraint_data_prorrogacao,
         'A Data de (Prorrogacao ou Bom para) nao pode ser menor que a data emissao',
         ['data_prorrogacao']), ]

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/financeiro/model/financeiro_titulo_data.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv, fields
import time


class financeiro_titulo(osv.Model):
    """
    Tabela de titulos.
    Conta todos os documentos a receber e a pagar
    Prefixo: fintit
    """

    from funcoes import _fintit_sacado
    from funcoes import _fintit_moeda_empresa
    from funcoes import _fintit_get_local_cobranca_tipo
    from funcoes import _fintit_get_valores
    from funcoes import _fintit_baixa
    from funcoes import _fintit_vr_pago
    from funcoes import _fintit_get_parametro
    from funcoes import _fintit_is_cheque
    from funcoes import _fintit_get_documento
    from funcoes import _constraint_data_prorrogacao
    from funcoes import _fintit_get_flag
    from funcoes import _fintit_boleto_dados


    """
    PREFIXO PARA NOMES DAS COLUNAS DO FINANCEIRO:

    fintit_

    Ex: fintit_parcela, fintit_vr_desconto, ......
    """

    _name = 'financeiro.titulo'
    _rec_name = 'documento'
    _columns = {
        ######## _____________ integer ____________________
        'id': fields.integer('ID', readonly=True),
        'parcela': fields.integer('Parcela'), # Numero da parcela do documento.
        'bordero': fields.integer('Bordero'), # Numero do bordero
        'fintit_chq_banco': fields.integer('Banco', select=True, help='Numero do banco no Banco Central'),
        'fintit_chq_agencia': fields.integer('Agencia', select=True, help='Numero da agencia bancaria'),

        ######## _____________ float ____________________
        'saldo': fields.float('Saldo', digits=(15, 2)), # Valor do saldo devedor
        'taxa_adm': fields.float('Taxa de administracao', digits=(15, 2)),
        # Valor cobrado pela administradora do cartao, a ser deduzida do valor do titulo na baixa do documento.
        'vr_multa': fields.float('Valor multa', digits=(15, 2)), # Valor da multa pelo atraso
        'vr_original': fields.float('Valor', digits=(15, 2), required=True),
        'vr_juros_dia': fields.float('Valor juros p/dia', digits=(15, 4)), # Valor dos juros por dia de atraso
        'vr_desconto': fields.float('Vr desconto', digits=(15, 2)), # Valor do desconto
        'fintit_vr_acrescimo': fields.float('Vr acrescimo', digits=(15, 2),
                                            help='Valor a ser adicionado ao valor do titulo no '
                                                 'momento da baixa.'),

        ######## _____________ char ____________________
        'fintit_chq_conta': fields.char('Conta', size=10, oldname="chq_conta"), # numero da conta
        'documento': fields.char('Documento', size=30, required=True, select=True), # Numero do documento.
        'observacoes': fields.text('Informacoes complementares'), #dados ou informacoes complementares do titulo
        'fintit_chq_emitente': fields.char('CPF/CNPJ Emitente', size=19, select=True),
        'fintit_nro_autorizacao_cartao': fields.char('Autorizacao', size=10,
                                                     help='Numero de autorizacao qdo for referente a cartao de credito'),

        ######## _____________ date/time ____________________
        'data_aceite': fields.date('Data aceite'), # Data do aceite
        'repasse_data': fields.date('Data de repasse'),
        'data_emissao': fields.date('Emissao', required=True, select=True), # data de emissao do titulo
        'data_vencimento': fields.date('Vencimento original', required=True, select=True),
        'multa_apos_data': fields.date('Multa apos dia'), # Data para cobranca da multa
        'data_prorrogacao': fields.date('Vencimento', required=True, select=True),
        'data_limite_desconto': fields.date('Data limite desconto'), # Data limite para o desconto
        'data_cancelamento': fields.date('Data Cancelamento'), # Data de cancelamento do cupom
        'create_date': fields.datetime('Data criacao'),

        ######## _____________ function ____________________
        'juros': fields.function(_fintit_baixa, multi="baixa", type="float", digits=(15, 2), method=True, store=True,
                                 string='Juros'),
        'fintit_valor_pago': fields.function(_fintit_vr_pago, type="float", digits=(15, 2), method=True, store=False,
                                 string='Valor Pago'),

        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'multa': fields.function(_fintit_baixa, multi="baixa", type="float", digits=(15, 2), method=True, store=True,
                                 string='Multa'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'desconto': fields.function(_fintit_baixa, multi="baixa", type="float", method=True, store=True,
                                    string='Desconto'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'data_baixa': fields.function(_fintit_baixa, multi="baixa", type="date", digits=(15, 2), method=True,
                                      store=True, string='Data da Baixa'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'data_pagamento': fields.function(_fintit_baixa, multi="baixa", type='date', method=True, store=True,
                                          string='Data Pagamento'),
        # Campos recebem os valores da tabela de baixa, utilizados na tree e search view do financeiro Titulos a Receber > Recebidos
        'fintit_flag': fields.function(_fintit_get_parametro, multi="parametros", type="boolean", method=True,
                                       store=False, string='Flag'),
        'fintit_parametro_local_cobranca': fields.function(_fintit_get_parametro, multi="parametros", type="boolean",
                                                           method=True, store=False, string='Local Cobranca'),
        'fintit_usar_centro_custos_e_eventos': fields.function(_fintit_get_parametro, multi="parametros",
                                                               type="boolean", method=True, store=False,
                                                               string='Centro custo e eventos'),
        'fintit_ocorrencia_ids': fields.function(_fintit_get_parametro, multi='parametros',
                                                 type='one2many', method=True, store=False,
                                                 string='Ocorrencias', relation='adm.ocorrencia'),
        'fintit_tipo_local_cobranca': fields.function(_fintit_get_local_cobranca_tipo, type="char",
                                                      method=True, store=False,
                                                      string="Tipo Local Cobranca"),
        'fintit_atraso_dias': fields.function(_fintit_get_valores, type="integer", method=True,
                                              store=False, multi="fintit_valores",
                                              string="Atraso(Dias)"),
        'fintit_cheque': fields.function(_fintit_is_cheque, type="boolean", method=True, store=True,
                                         string="Cheque"),
        'fintit_encargos': fields.function(_fintit_get_valores, type="float", method=True,
                                           store=False, multi="fintit_valores", string="Encargos"),
        'fintit_boleto_nosso_numero': fields.function(_fintit_boleto_dados, method=True,
                                                      string='Nosso numero', type='char', size=20,
                                                      store=False, multi='boleto'),
        'fintit_boleto_codigo_barras': fields.function(_fintit_boleto_dados, method=True,
                                                       string='Codigo de barras', type='char',
                                                       size=48, store=False, multi='boleto'),
        'fintit_saldo_corrigido': fields.function(_fintit_get_valores, method=True,
                                                  string='Saldo corrigido', type='float',
                                                  multi="fintit_valores", digits=(15, 2)),

        ######## _____________ selection ____________________
        'state': fields.selection(
            [('A', 'Em aberto'), ('B', 'Baixado'), ('D', 'Devolvido'), ('R', 'Reapresentado'), ('C', 'Cancelado')],
            'Situacao', required=True, readonly=True, size=1),
        'state_banco': fields.selection(
            [('N', 'Nao enviado'), ('E', 'Enviado'), ('C', 'confirmado'), ('R', 'Rejeitado'), ('B', 'Baixado'), ('A', 'Cancelado')],
            'Situacao no banco', size=1, readonly=True),
        'tipo_titulo': fields.selection([('R', 'Receber'), ('P', 'Pagar')], 'Tipo titulo', required=True, size=1),
        # Tipo de titulo. \nR=a Receber, \nP=a Pagar
        'tipo_sacado': fields.selection([('C', 'Cliente'), ('F', 'Fornecedor'), ('O', 'Outros')], 'Tipo sacado',
                                        required=True, size=1), # Tipo de sacado\nC=Cliente, \nF=Fornecedor, \nO=Outros
        'tipo_lancamento': fields.selection([('M', 'Manual'), ('A', 'Automatico')], 'Tipo de lancamento', size=1),
        #Tipo de lancamento. \nM Entrada do titulo feito manualmente \nA Entrada do titulo feito automaticamente pelo sistema

        ######## _____________ one2many ____________________
        'cheque_devolucao_ids': fields.one2many('financeiro.cheque.devolucao', 'cheque_id', 'Devolucao', readonly=True),
        # Relacao das devolucoes de um  cheque
        'titulo_historico_ids': fields.one2many('financeiro.titulo.historico', 'titulo_id', 'Historico'),
        'fintit_gerencialmov_ids': fields.one2many('gerencial.movimento', 'titulo_id', 'Movimento'),
        'fintit_baixa_ids': fields.one2many('financeiro.titulo.baixa', 'titulo_id', 'Baixas do Titulo'),
        'fintit_boleto_ids': fields.one2many('financeiro.titulo.boleto', 'fintib_titulo_id',
                                             'Boletos'),

        ######## _____________ many2one ____________________
        'fatura_id': fields.many2one("financeiro.fatura", 'Fatura', ondelete="cascade", select=True), # id da fatura
        'pessoa_id': fields.many2one("adm.pessoa", 'Cliente', ondelete="restrict", required=True, select=True),
        # Id do parceiro(cliente/Fornecedor)
        'company_id': fields.many2one("res.company", 'Empresa', ondelete="cascade", required=True, select=True), # Id da empresa
        'doc_tipo_id': fields.many2one("documento.documento.tipo", 'Tipo de documento', ondelete="restrict",
                                       required=True, select=True), # id do Tipo de documento
        'adm_moeda_id': fields.many2one("adm.moeda", 'Moeda', required=True, ondelete="restrict", select=True),
        # Moeda utilizada no titulo
        'titulo_parent_id': fields.many2one('financeiro.titulo', 'Titulo relacionado', ondelete="restrict"),
        'local_cobranca_id': fields.many2one("financeiro.local.cobranca", 'Local cobranca', ondelete="restrict",
                                             required=True, select=True), # id do local de cobranca
        'repasse_pessoa_id': fields.many2one("adm.pessoa", 'Repassado para', ondelete="restrict", select=True),
        'natureza_cobranca_id': fields.many2one("financeiro.natureza.cobranca", 'Natureza cobranca',
                                                ondelete="restrict", select=True), # id da natureza de cobranca
        'fintit_cancel_user_id': fields.many2one("res.users", 'Usuario', oldname="user"),
        # id do usuario logado no sistema
        'fintit_operacao_id': fields.many2one('financeiro.operacoes', 'Operacao'),
        'fintit_renegociacao_fatura_ids': fields.many2many(
            'financeiro.fatura', 'fatura_renegociacao_titulo', 'titulo_id', 'fatura_id'
            ,'Fatura de renegociacao', select=True),
        'fintit_pgm_banco_pagador': fields.char('Banco pagador', size=3, select=1,
                                                help='Banco onde o titulo foi enviado para pagamento'),
        'fintit_pgm_data_pagamento': fields.date('Data para pagamento',
                                                 help='Data definida para pagamento do titulo'),
        'fintit_pgm_valor': fields.float('Valor para pagamento',
                                         help='Valor definido para pagamento'),
        'fintit_pgm_operacao': fields.selection([('000', '000-Inclusao de pagamento'),
                                                 ('517', '517-Alteracao de valor de pagamento'),
                                                 ('519', '519-Alteracao de data de pagamento'),
                                                 ('999', '999-Exclusao de pagamento incluido')],
                                                'Operacao', size=3),
    }

    _order = 'data_prorrogacao, pessoa_id, documento desc'
    _defaults = {
        'state': lambda *a: 'A',
        'state_banco': lambda *a: 'N',
        'tipo_lancamento': lambda *a: 'M',
        'tipo_sacado': _fintit_sacado,
        'tipo_titulo': 'P',
        'company_id': lambda s, cr, uid, c: s.pool.get('adm.empresa.objeto').getEmpresa(cr, uid, s._name, context=c),
        'data_emissao': lambda *a: time.strftime('%Y-%m-%d'),
        'adm_moeda_id': _fintit_moeda_empresa,
        'doc_tipo_id': lambda s, cr, uid, c:
        s.pool.get('documento.documento.tipo').search(cr, uid, [('sigla', '=', 'DP')], context=c)[0],
        'fintit_flag': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={'fintit_flag': True,
                                                                                  'entrada_titulo_receber': True}),
        'fintit_parametro_local_cobranca': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={
            'fintit_parametro_local_cobranca': True, 'entrada_titulo_receber': True}),
        'fintit_usar_centro_custos_e_eventos': lambda s, cr, uid, c: s._fintit_get_flag(cr, uid, context={
            'fintit_usar_centro_custos_e_eventos': True, 'entrada_titulo_receber': True}),
        'documento': _fintit_get_documento,
    }

    _constraints = [
        (_constraint_data_prorrogacao,
         'A Data de (Prorrogacao ou Bom para) nao pode ser menor que a data emissao',
         ['data_prorrogacao']), ]
